@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import enum
 import re
 import sys
 from abc import ABC
@@ -9,6 +10,7 @@ from typing import List, Optional, TypeVar, Union, Any
 import betterproto
 import yaml
 from pydantic import validator, Field, root_validator
+from pydantic_yaml import YamlIntEnum, YamlStrEnum
 
 from bigeye_sdk.bigconfig_validation.validation_functions import safe_split_dict_entry_lines, must_be_list_validator
 from bigeye_sdk.bigconfig_validation.yaml_model_base import YamlModelWithValidatorContext
@@ -532,11 +534,33 @@ class SimpleSLA(YamlModelWithValidatorContext, DatawatchFacade):
         return c
 
 
+class BucketSize(YamlStrEnum):
+    DAY = "DAY"  # 86400
+    HOUR = "HOUR"  # 3600
+
+    def to_seconds(self):
+        if self == BucketSize.DAY:
+            return 86400
+        elif self == BucketSize.HOUR:
+            return 3600
+        else:
+            return 86400  # defaults to day.
+
+    @classmethod
+    def from_seconds(cls, seconds: int) -> Union[int, BucketSize]:
+        if seconds == 86400:
+            return BucketSize.DAY
+        elif seconds == 3600:
+            return BucketSize.HOUR
+        else:
+            return seconds
+
+
 class SimpleLookback(YamlModelWithValidatorContext):
     lookback_window: Optional[SimpleTimeInterval] = SimpleTimeInterval(interval_type=SimpleTimeIntervalType.DAYS,
-                                                                interval_value=2)
+                                                                       interval_value=2)
     lookback_type: Optional[SimpleLookbackType] = SimpleLookbackType.DATA_TIME
-    bucket_size_seconds: Optional[int] = 86400  # 1 day.
+    bucket_size: Optional[Union[int, BucketSize]] = BucketSize.DAY
 
 
 class SimpleMetricDefinition(YamlModelWithValidatorContext, DatawatchFacade):
@@ -544,14 +568,13 @@ class SimpleMetricDefinition(YamlModelWithValidatorContext, DatawatchFacade):
     metric_type: SimpleMetricType = None
     metric_name: Optional[str] = None
     description: Optional[str] = None
-    schedule_frequency: Optional[SimpleTimeInterval] = SimpleTimeInterval(interval_type=SimpleTimeIntervalType.HOURS,
-                                                                          interval_value=6)
+    schedule_frequency: Optional[SimpleTimeInterval] = None
     conditions: Optional[List[str]] = None
     group_by: Optional[List[str]] = None
     threshold: Optional[SimpleThreshold] = None
     notification_channels: Optional[List[SimpleNotificationChannel]] = None
     parameters: Optional[List[SimpleMetricParameter]] = None
-    lookback: Optional[SimpleLookback] = None
+    lookback: Optional[SimpleLookback] = SimpleLookback()
     muted_until_epoch_seconds: Optional[int] = 0
     sla_ids: Optional[List[int]] = Field(default_factory=lambda: [])
 
@@ -560,7 +583,7 @@ class SimpleMetricDefinition(YamlModelWithValidatorContext, DatawatchFacade):
         metric_type = values['metric_type']
 
         if threshold:
-            """For the case that a user as specifically defined a metric"""
+            """For the case that a user has specifically defined a metric"""
             return threshold
         elif not metric_type:
             """For the case where this is a saved metric reference."""
@@ -583,6 +606,24 @@ class SimpleMetricDefinition(YamlModelWithValidatorContext, DatawatchFacade):
 
         return threshold
 
+    @validator('schedule_frequency', always=True, pre=False)
+    def set_default_schedule_frequency(cls, schedule_frequency, values):
+        metric_type = values['metric_type']
+
+        if schedule_frequency:
+            """For the case that a user has specifically defined a metric"""
+            return schedule_frequency
+        elif not metric_type:
+            """For the case where this is a saved metric reference."""
+            return schedule_frequency
+        elif metric_type \
+                and metric_type in SimpleMetricType.get_freshness_metric_types():
+            """Freshness metrics should execute every 6 hours by default WIZ-1623"""
+            return SimpleTimeInterval(interval_type=SimpleTimeIntervalType.HOURS, interval_value=6)
+        else:
+            """All other metrics should execute every 24 hours by default WIZ-1623"""
+            return SimpleTimeInterval(interval_type=SimpleTimeIntervalType.HOURS, interval_value=24)
+
     def get_error_lines(self) -> List[str]:
         """
         Override from super.  Returns object serialized to yaml and split to lines.  Used to search files.  If this is
@@ -698,7 +739,7 @@ class SimpleMetricDefinition(YamlModelWithValidatorContext, DatawatchFacade):
 
         builder.lookback = SimpleLookback(lookback_window=SimpleTimeInterval.from_datawatch_object(obj.lookback),
                                           lookback_type=SimpleLookbackType.from_datawatch_object(obj.lookback_type),
-                                          bucket_size_seconds=obj.grain_seconds)
+                                          bucket_size=BucketSize.from_seconds(obj.grain_seconds))
 
         builder.muted_until_epoch_seconds = obj.muted_until_epoch_seconds
 
@@ -741,7 +782,7 @@ class SimpleMetricDefinition(YamlModelWithValidatorContext, DatawatchFacade):
             if self.lookback.lookback_type:
                 builder.lookback_type = self.lookback.lookback_type.to_datawatch_object()
 
-            builder.grain_seconds = self.lookback.bucket_size_seconds
+            builder.grain_seconds = self.lookback.bucket_size.to_seconds()
 
         builder.muted_until_epoch_seconds = self.muted_until_epoch_seconds
 
